<?php
/**
 * Plugin Name: WP-Share to XING
 * Plugin URI: http://blog.ppfeufer.de/wordpress-plugin-wp-share-to-xing/
 * Description: This plugin will install a XING-Button to share a link to your XING-Contacts.
 * Version: 1.2.0
 * Author: H.-Peter Pfeufer
 * Author URI: http://ppfeufer.de
 */

/**
 * Changelog:
 * 		= 1.2.0 (03.12.2010) =
 * 		Add: Maintenance Options
 * 		Add: Flattr-Button for support :-)
 * 		Update: Databasehandling
 * 		Update: German translation
 * 		Test: Ready for WordPress 3.1 (tested on WordPress 3.1-beta1)
 *
 * 		= 1.1.1 =
 * 		Added new translation files
 *
 * 		= 1.1.0 =
 * 		Added small button
 * 		Updated german translation
 *
 * 		= 1.0.3 =
 * 		Replaced old translation-files with new
 *
 * 		= 1.0.2 =
 * 		Removed deprecated function for language support
 * 		Added new language support function
 *
 * 		= 1.0.1 =
 * 		Removed testlink in RSS and added link to post
 *
 *		= 1.0.0 =
 *		Initial Release
 */

/**
 * Optionen zurückgeben.
 *
 * @param string $parameter
 */
$wp_share_to_xing_options = get_option('wp_share_to_xing_settings');
if($wp_share_to_xing_options['wp_share_to_xing_maintenance_reset'] == 1) {
	wp_share_to_xing_reset_options();

	$wp_share_to_xing_options = get_option('wp_share_to_xing_settings');
	$action = 'reset';
} elseif($wp_share_to_xing_options['wp_share_to_xing_maintenance_clear'] == 1) {
	wp_share_to_xing_delete_options();

	$wp_share_to_xing_options = get_option('wp_share_to_xing_settings');
	$action = 'clear';
} elseif($_GET['updated'] == 'true') {
	$action = 'saved';
}
/**
 * Reset und Delete abfangen
 */
function wp_share_to_xing_reset_options() {
	wp_share_to_xing_delete_options();
	wp_share_to_xing_activate();
	return;
}

function wp_share_to_xing_delete_options() {
	delete_option('wp_share_to_xing_display_archive');
	delete_option('wp_share_to_xing_display_category');
	delete_option('wp_share_to_xing_display_feed');
	delete_option('wp_share_to_xing_display_front');
	delete_option('wp_share_to_xing_where');
	delete_option('wp_share_to_xing_rss_where');
	delete_option('wp_share_to_xing_style');
	delete_option('wp_share_to_xing_display_page');
	delete_option('wp_share_to_xing_version');
	delete_option('wp_share_to_xing_settings');

	return;
}

function wp_share_to_xing_get_option ($parameter = '') {
	global $wp_share_to_xing_options;

	if ($parameter == '') {
		return $wp_share_to_xing_options;
	} else {
		return $wp_share_to_xing_options[$parameter];
	}
}

/**
 * Button Menü zum Dashboard hinzufügen
 */
function wp_share_to_xing_options() {
	add_menu_page('Share to XING', 'Share to XING', 8, basename(__FILE__), 'wp_share_to_xing_options_page');
	add_submenu_page(basename(__FILE__), __('Settings'), __('Settings'), 8, basename(__FILE__), 'wp_share_to_xing_options_page');
}

/**
 * Buttons generieren
 */
function wp_share_to_xing_generate_button() {
	$url = urlencode(get_permalink($post->ID));
	return '<div class="wp_share_to_xing_button" style="' . wp_share_to_xing_get_option('wp_share_to_xing_style') . '">
				<a href="http://www.xing.com/app/user?op=share;url=' . $url . ';title=' . urlencode(get_the_title()) . ';provider=' . urlencode(get_bloginfo('name'))  .'" target="_blank" title="' . __('Show it your XING Contacts', 'wp_share_to_xing') . '"><img src="' . plugins_url(basename(dirname(__FILE__))) . '/img/xing_icon_' . wp_share_to_xing_get_option('wp_share_to_xing_version') . 'x' . wp_share_to_xing_get_option('wp_share_to_xing_version') . '.png" width="' . wp_share_to_xing_get_option('wp_share_to_xing_version') . '" height="' . wp_share_to_xing_get_option('wp_share_to_xing_version') . '" alt="Ihren XING-Kontakten zeigen" /></a>
			</div>';
}

function wp_share_to_xing_generate_static_button() {
	if(get_post_status($post->ID) == 'publish') {
		$url = urlencode(get_permalink($post->ID));
		return '<div class="wp_share_to_xing_button" style="' . wp_share_to_xing_get_option('wp_share_to_xing_style') . '">
					<a href="http://www.xing.com/app/user?op=share;url=' . $url . ';title=' . urlencode(get_the_title()) . ';provider=' . urlencode(get_bloginfo('name'))  .'" target="_blank" title="' . __('Show it your XING Contacts', 'wp_share_to_xing') . '"><img src="' . plugins_url(basename(dirname(__FILE__))) . '/img/xing_icon_' . wp_share_to_xing_get_option('wp_share_to_xing_version') . 'x' . wp_share_to_xing_get_option('wp_share_to_xing_version') . '.png" width="' . wp_share_to_xing_get_option('wp_share_to_xing_version') . '" height="' . wp_share_to_xing_get_option('wp_share_to_xing_version') . '" alt="Ihren XING-Kontakten zeigen" /></a>
				</div>';
	} else {
		return;
	}
}

/**
 * Gets run when the content is loaded in the loop
 */
function wp_share_to_xing_update($content) {
	global $post;

	/**
	 * Manual Option
	 */
	if(wp_share_to_xing_get_option('wp_share_to_xing_where') == 'manual') {
		return $content;
	}

	/**
	 * Sind wir auf einer CMS-Seite?
	 */
	if(wp_share_to_xing_get_option('wp_share_to_xing_display_page') == null && is_page()) {
		return $content;
	}

	/**
	 * Sind wir auf der Startseite?
	 */
	if(wp_share_to_xing_get_option('wp_share_to_xing_display_front') == null && is_home()) {
		return $content;
	}

	/**
	 * Sind wir in der Achiveanzeige?
	 */
	if(wp_share_to_xing_get_option('wp_share_to_xing_display_archive') == null && is_archive()) {
		return $content;
	}

	/**
	 * Sind wir in der Kategorieanzeige?
	 */
	if(wp_share_to_xing_get_option('wp_share_to_xing_display_category') == null && is_category()) {
		return $content;
	}

	/**
	 * Ist es ein Feed
	 */
	if (is_feed()) {
		$button = wp_share_to_xing_generate_static_button();
		$where = 'wp_share_to_xing_rss_where';
	} else {
		$button = wp_share_to_xing_generate_button();
		$where = 'wp_share_to_xing_where';
	}

	/**
	 * Soll der Button im Feed ausgeblendet werden?
	 */
	if (is_feed() && wp_share_to_xing_get_option('wp_share_to_xing_display_feed') == null) {
		return $content;
	}

	/**
	 * Wurde der Shortcode genutzt
	 */
	if(wp_share_to_xing_get_option($where) == 'shortcode') {
		return str_replace('[share_to_xing]', $button, $content);
	} else {
		/**
		 * Wenn wir den Button abgeschalten haben
		 */
		if(get_post_meta($post->ID, 'wp_share_to_xing') == null) {
			if(wp_share_to_xing_get_option($where) == 'beforeandafter') {
				/**
				 * Vor und nach dem Beitrag einfügen
				 */
				return $button . $content . $button;
			} else if(wp_share_to_xing_get_option($where) == 'before') {
				/**
				 * Vor dem Beitrag einfügen
				 */
				return $button . $content;
			} else {
				/**
				 * Nach dem Beitrag einfügen
				 */
				return $content . $button;
			}
		} else {
			/**
			 * Keinen Button einfügen
			 */
			return $content;
		}
	}
}

/**
 * Manuelle Ausgabe
 */
function wp_share_to_xing() {
	if(wp_share_to_xing_get_option('wp_share_to_xing_where') == 'manual') {
		return wp_share_to_xing_generate_button();
	} else {
		return false;
	}
}

/**
 * Filter durch Vorschau entfernen
 * @param string $content
 */
function wp_share_to_xing_remove_filter($content) {
	if(!is_feed()) {
		remove_action('the_content', 'wp_share_to_xing_update');
	}
	return $content;
}

/**
 * Meta-Tag 'wp_share_to_xing-title' setzen.
 */
function wp_share_to_xing_head() {
	/**
	 * Sind wir in einem Artikel?
	 */
	if(is_single()) {
		global $post;
		$title = get_the_title($post->ID);
		echo '<!-- WP-Share to Xing by H.-Peter Pfeufer -->' . "\n" . '<meta name="wp_share_to_xing-title" content="' . strip_tags($title) . '" />' . "\n";
	}
}

/**
 * Optionsseite generieren
 */
function wp_share_to_xing_options_page() {
	global $action;
	/**
	 * JavaScript für den Flattr-Button einfügen
	 */
	$api_script = plugins_url(basename(dirname(__FILE__)) . '/js/flattr.js');
	?>
	<script type="text/javascript" src="<?php echo $api_script; ?>"></script>
	<div class="wrap">
		<div class="icon32" id="icon-options-general"><br /></div>
		<h2><?php _e('Settings for WP-Share to XING', 'wp_share_to_xing'); ?></h2>
		<p><?php _e('This plugin will install the WP-Share to XING widget for each of your blog posts.', 'wp_share_to_xing'); ?></p>

		<?php if ($action == 'saved') : ?>
			<div class="updated fade" id="message">
				<p><strong><?php _e('Settings saved', 'wp-twitter-button');?></strong></p>
			</div>
		<?php endif; ?>
		<?php if ($action == 'reset') : ?>
			<div class="updated fade" id="message">
				<p><strong><?php _e('Settings resetted', 'wp-twitter-button');?></strong></p>
			</div>
		<?php endif; ?>
		<?php if ($action == 'clear') : ?>
			<div class="updated fade" id="message">
				<p><strong><?php _e('Settings cleared', 'wp-twitter-button');?></strong></p>
			</div>
		<?php endif; ?>
		<form method="post" action="options.php">
			<?php
			// New way of setting the fields, for WP 2.7 and newer
			if(function_exists('settings_fields')) {
				settings_fields('wp_share_to_xing-options');
			}
			?>
			<table class="form-table">
				<tr>
					<th scope="row" valign="top"><?php _e('Display', 'wp_share_to_xing'); ?></th>
					<td>
						<div style="float:right; text-align:center; width:120px;">
							<?php _e('Support me if you like the Plugin', 'wp_share_to_xing'); ?><br />
							<a class="FlattrButton" style="display:none;" href="http://blog.ppfeufer.de/wordpress-plugin-wp-share-to-xing/"></a>
						</div>
						<div>
							<input type="checkbox" value="1" <?php if(wp_share_to_xing_get_option('wp_share_to_xing_display_page') == '1') echo 'checked="checked"'; ?> name="wp_share_to_xing_settings[wp_share_to_xing_display_page]" id="wp_share_to_xing_settings[wp_share_to_xing_display_page]" group="wp_share_to_xing_display" />
							<label for="wp_share_to_xing_settings[wp_share_to_xing_display_page]"><?php _e('Display the button on pages', 'wp_share_to_xing'); ?></label>
						</div>
						<div>
							<input type="checkbox" value="1" <?php if(wp_share_to_xing_get_option('wp_share_to_xing_display_front') == '1') echo 'checked="checked"'; ?> name="wp_share_to_xing_settings[wp_share_to_xing_display_front]" id="wp_share_to_xing_settings[wp_share_to_xing_display_front]" group="wp_share_to_xing_display" />
							<label for="wp_share_to_xing_settings[wp_share_to_xing_display_front]"><?php _e('Display the button on front page (home)', 'wp_share_to_xing'); ?></label>
						</div>
						<div>
							<input type="checkbox" value="1" <?php if(wp_share_to_xing_get_option('wp_share_to_xing_display_archive') == '1') echo 'checked="checked"'; ?> name="wp_share_to_xing_settings[wp_share_to_xing_display_archive]" id="wp_share_to_xing_settings[wp_share_to_xing_display_archive]" group="wp_share_to_xing_display" />
							<label for="wp_share_to_xing_settings[wp_share_to_xing_display_archive]"><?php _e('Display the button on archive-view <em>(<strong>Note</strong>: not all themes support this option)</em>', 'wp_share_to_xing'); ?></label>
						</div>
						<div>
							<input type="checkbox" value="1" <?php if(wp_share_to_xing_get_option('wp_share_to_xing_display_category') == '1') echo 'checked="checked"'; ?> name="wp_share_to_xing_settings[wp_share_to_xing_display_category]" id="wp_share_to_xing_settings[wp_share_to_xing_display_category]" group="wp_share_to_xing_display" />
							<label for="wp_share_to_xing_settings[wp_share_to_xing_display_category]"><?php _e('Display the button on category-view <em>(<strong>Note</strong>: not all themes support this option)</em>', 'wp_share_to_xing'); ?></label>
						</div>
						<div>
							<input type="checkbox" value="1" <?php if(wp_share_to_xing_get_option('wp_share_to_xing_display_feed') == '1') echo 'checked="checked"'; ?> name="wp_share_to_xing_settings[wp_share_to_xing_display_feed]" id="wp_share_to_xing_settings[wp_share_to_xing_display_feed]" group="wp_share_to_xing_display" />
							<label for="wp_share_to_xing_settings[wp_share_to_xing_display_feed]"><?php _e('Display the button on rss-feed', 'wp_share_to_xing'); ?></label>
						</div>
					</td>
				</tr>
				<tr>
					<th scope="row" valign="top"><?php _e('Position', 'wp_share_to_xing'); ?></th>
					<td>
						<select name="wp_share_to_xing_settings[wp_share_to_xing_where]">
							<option <?php if(wp_share_to_xing_get_option('wp_share_to_xing_where') == 'before') echo 'selected="selected"'; ?> value="before"><?php _e('Before', 'wp_share_to_xing'); ?></option>
							<option <?php if(wp_share_to_xing_get_option('wp_share_to_xing_where') == 'after') echo 'selected="selected"'; ?> value="after"><?php _e('After', 'wp_share_to_xing'); ?></option>
							<option <?php if(wp_share_to_xing_get_option('wp_share_to_xing_where') == 'beforeandafter') echo 'selected="selected"'; ?> value="beforeandafter"><?php _e('Before and After', 'wp_share_to_xing'); ?></option>
							<option <?php if(wp_share_to_xing_get_option('wp_share_to_xing_where') == 'shortcode') echo 'selected="selected"'; ?> value="shortcode"><?php _e('Shortcode [share_to_xing]', 'wp_share_to_xing'); ?></option>
							<option <?php if(wp_share_to_xing_get_option('wp_share_to_xing_where') == 'manual') echo 'selected="selected"'; ?> value="manual"><?php _e('Manual', 'wp_share_to_xing'); ?></option>
						</select>
					</td>
				</tr>
				<tr>
					<th scope="row" valign="top"><?php _e('RSS Position', 'wp_share_to_xing'); ?></th>
					<td>
						<select name="wp_share_to_xing_settings[wp_share_to_xing_rss_where]">
							<option <?php if (wp_share_to_xing_get_option('wp_share_to_xing_rss_where') == 'before') echo 'selected="selected"'; ?> value="before"><?php _e('Before', 'wp_share_to_xing'); ?></option>
							<option <?php if (wp_share_to_xing_get_option('wp_share_to_xing_rss_where') == 'after') echo 'selected="selected"'; ?> value="after"><?php _e('After', 'wp_share_to_xing'); ?></option>
							<option <?php if (wp_share_to_xing_get_option('wp_share_to_xing_rss_where') == 'beforeandafter') echo 'selected="selected"'; ?> value="beforeandafter"><?php _e('Before and After', 'wp_share_to_xing'); ?></option>
							<option <?php if (wp_share_to_xing_get_option('wp_share_to_xing_where') == 'shortcode') echo 'selected="selected"'; ?> value="shortcode"><?php _e('Shortcode [share_to_xing]', 'wp_share_to_xing'); ?></option>
						</select>
					</td>
				</tr>
				<tr>
					<th scope="row" valign="top"><?php _e('Type', 'wp_share_to_xing'); ?></th>
					<td>
						<div style="float:left; width:32%;">
							<p>
								<input type="radio" value="32" <?php if (wp_share_to_xing_get_option('wp_share_to_xing_version') == '32') echo 'checked="checked"'; ?> name="wp_share_to_xing_settings[wp_share_to_xing_version]" id="wp_share_to_xing_settings[wp_share_to_xing_version_big]" group="wp_share_to_xing_version"/>
								<label for="wp_share_to_xing_settings[wp_twitter_version_large]"><?php _e('32 x 32 Pixel', 'wp_share_to_xing'); ?></label>
							</p>
							<p><img src="<?php echo plugins_url(basename(dirname(__FILE__))); ?>/img/xing_icon_32x32.png" /></p>
						</div>
						<div style="float:left; width:32%;">
							<p>
								<input type="radio" value="16" <?php if (wp_share_to_xing_get_option('wp_share_to_xing_version') == '16') echo 'checked="checked"'; ?> name="wp_share_to_xing_settings[wp_share_to_xing_version]" id="wp_share_to_xing_settings[wp_share_to_xing_version_small]" group="wp_share_to_xing_version" />
								<label for="wp_share_to_xing_settings[wp_share_to_xing_version]"><?php _e('16 x 16 Pixel', 'wp_share_to_xing'); ?></label>
							</p>
							<p><img src="<?php echo plugins_url(basename(dirname(__FILE__))); ?>/img/xing_icon_16x16.png" /></p>
						</div>
					</td>
				</tr>
				<tr>
					<th scope="row" valign="top"><label for="wp_share_to_xing_settings[wp_share_to_xing_style]"><?php _e('Styling', 'wp_share_to_xing'); ?></label></th>
					<td>
						<input type="text" value="<?php echo htmlspecialchars(wp_share_to_xing_get_option('wp_share_to_xing_style')); ?>" name="wp_share_to_xing_settings[wp_share_to_xing_style]" id="wp_share_to_xing_settings[wp_share_to_xing_style]" />
						<span class="description"><?php _e('Add style to the div that surrounds the button E.g. <code>float: left; margin-right: 10px;</code>', 'wp_share_to_xing'); ?></span>
					</td>
				</tr>
				<tr>
					<th scope="row" valign="top"><?php _e('Maintenance', 'wp_share_to_xing'); ?></th>
					<td>
						<div>
							<input type="checkbox" value="1" <?php //if(wp_twitter_get_option('wp_twitter_maintenance_reset') == '1') echo 'checked="checked"'; ?> name="wp_share_to_xing_settings[wp_share_to_xing_maintenance_reset]" id="wp_share_to_xing_settings[wp_share_to_xing_maintenance_reset]" group="wp_share_to_xing_maintenance" />
							<label for="wp_share_to_xing_settings[wp_share_to_xing_maintenance_reset]"><?php _e('Reset Options', 'wp_share_to_xing'); ?></label>
							<span class="description">
								(<?php _e('This will delete all options from database and restore the defaults', 'wp_share_to_xing'); ?>)
							</span>
						</div>
						<div>
							<input type="checkbox" value="1" <?php //if(wp_twitter_get_option('wp_twitter_maintenance_clear') == '1') echo 'checked="checked"'; ?> name="wp_share_to_xing_settings[wp_share_to_xing_maintenance_clear]" id="wp_share_to_xing_settings[wp_share_to_xing_maintenance_clear]" group="wp_share_to_xing_maintenance" />
							<label for="wp_share_to_xing_settings[wp_share_to_xing_maintenance_clear]"><?php _e('Clear Options', 'wp_share_to_xing'); ?></label>
							<span class="description">
								(<?php _e('This will delete all options from database', 'wp_share_to_xing'); ?>)
							</span>
						</div>
					</td>
				</tr>
			</table>
			<p class="submit"><input type="submit" name="Submit" value="<?php _e('Save Changes', 'wp_share_to_xing'); ?>" /></p>
		</form>
	</div>
<?php
}

function wp_share_to_xing_settings_link( $links, $file ) {
 	if( $file == 'wp-share-to-xing/wp-share-to-xing.php' && function_exists( "admin_url" ) ) {
		$settings_link = '<a href="' . admin_url( 'admin.php?page=wp-share-to-xing.php' ) . '">' . __('Settings') . '</a>';
		array_unshift( $links, $settings_link ); // before the other links
	}

	return $links;
}

/**
 * Variablen registrieren
 */
function wp_share_to_xing_init() {
	if(function_exists('register_setting')) {
		register_setting('wp_share_to_xing-options', 'wp_share_to_xing_settings');
	}

	/**
	 * Sprachdatei wählen
	 */
	if(function_exists('load_plugin_textdomain')) {
		load_plugin_textdomain('wp_share_to_xing', false, dirname(plugin_basename( __FILE__ )) . '/languages/');
	}
}

/**
 * Nur wenn User auch der Admin ist, sind die Adminotionen zu sehen
 */
if(is_admin()) {
	add_action('admin_menu', 'wp_share_to_xing_options');
	add_action('admin_init', 'wp_share_to_xing_init');
}

/**
 * Standardwerte setzen
 */
function wp_share_to_xing_activate() {
	$add_options = array(
		'wp_share_to_xing_where' => 'before',
		'wp_share_to_xing_rss_where' => 'before',
		'wp_share_to_xing_style' => 'float: right; margin-left: 10px;',
		'wp_share_to_xing_display_page' => '1',
		'wp_share_to_xing_display_front' => '0',
		'wp_share_to_xing_display_archive' => '0',
		'wp_share_to_xing_display_category' => '0',
		'wp_share_to_xing_display_feed' => '0',
		'wp_share_to_xing_version' => '32'
	);

	if (is_array(get_option('wp_share_to_xing_settings'))) {
		add_option('wp_share_to_xing_settings', $add_options);;
	} else {
		foreach($add_options as $key => $value) {
			if($old = get_option($key)) {
				$add_options[$key] = $old;

				delete_option($key);
			}
		}

		delete_option('wp_share_to_xing_display_archive');
		delete_option('wp_share_to_xing_display_category');
		delete_option('wp_share_to_xing_display_feed');
		delete_option('wp_share_to_xing_display_front');
		delete_option('wp_share_to_xing_where');
		delete_option('wp_share_to_xing_rss_where');
		delete_option('wp_share_to_xing_style');
		delete_option('wp_share_to_xing_display_page');
		delete_option('wp_share_to_xing_version');

		update_option('wp_share_to_xing_settings', $add_options);
	}
}

/**
 * Filter zum Blog hinzufügen
 */
add_filter('the_content', 'wp_share_to_xing_update', 8);
add_filter('get_the_excerpt', 'wp_share_to_xing_remove_filter', 9);
add_filter('plugin_action_links', 'wp_share_to_xing_settings_link', 9, 2 );

/**
 * Header erweitern
 */
add_action('wp_head', 'wp_share_to_xing_head');

/**
 * Button aktivieren
 */
register_activation_hook(__FILE__, 'wp_share_to_xing_activate');
?>